import { Component } from '@angular/core';
import { Router } from '@angular/router';
import { AlertController } from '@ionic/angular';

@Component({
  selector: 'app-tab4',
  templateUrl: './tab4.page.html',
  styleUrls: ['./tab4.page.scss'],
  standalone:false,
})
export class Tab4Page {
  isLoggedIn = true; // 根据实际登录状态切换
  user = {
    name: '张老农',
    avatar: 'assets/icon/farmer-avatar.png',
    type: 'farmer', // farmer/expert
    fields: 5,
    solved: 28,
    exp: 356
  };

  constructor(
    private router: Router,
    private alertCtrl: AlertController
  ) {}

  // 导航到设置页面
  goToSettings() {
    this.router.navigate(['/settings']);
  }

  // 导航到登录页面
  goToLogin() {
    this.router.navigate(['/login']);
  }

  // 导航到注册页面
  goToRegister() {
    this.router.navigate(['/register']);
  }

  // 导航到农田管理
  goToFields() {
    this.router.navigate(['/my-fields']);
  }

  // 导航到我的提问
  goToQuestions() {
    this.router.navigate(['/my-questions']);
  }

  // 导航到收藏
  goToFavorites() {
    this.router.navigate(['/favorites']);
  }

  // 导航到反馈
  goToFeedback() {
    this.router.navigate(['/feedback']);
  }

  // 导航到关于我们
  goToAbout() {
    this.router.navigate(['/about']);
  }

  // 退出登录
  async logout() {
    const alert = await this.alertCtrl.create({
      header: '确认退出',
      message: '确定要退出当前账号吗？',
      buttons: [
        {
          text: '取消',
          role: 'cancel'
        },
        {
          text: '退出',
          handler: () => {
            this.isLoggedIn = false;
            // 这里添加实际的退出登录逻辑
          }
        }
      ]
    });
    await alert.present();
  }
}